@@ -62,7 +62,7 @@ if IS_WINDOWS:
     )
 
     def initscr():
-        import curses  # pylint: disable=redefined-outer-name,reimported  # special case for monkeypatch
+        import curses  # noqa: I001  # pylint: disable=redefined-outer-name,reimported  # special case for monkeypatch
 
         import _curses
 
@@ -103,7 +103,7 @@ _curses_colours = {  # pylint: disable=consider-using-namedtuple-or-dataclass  #
 
 
 class Screen(BaseScreen, RealTerminal):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.curses_pairs = [(None, None)]  # Can't be sure what pair 0 will default to
         self.palette = {}
@@ -124,7 +124,7 @@ class Screen(BaseScreen, RealTerminal):
         After calling this function get_input will include mouse
         click events along with keystrokes.
         """
-        enable = bool(enable)  # noqa: FURB123,RUF100
+        enable = bool(enable)
         if enable == self._mouse_tracking_enabled:
             return
 
@@ -666,7 +666,7 @@ class _test:
             r.text = ([t.ljust(cols) for t in text] + [""] * rows)[:rows]
             r.attr = (attr + [[] for _ in range(rows)])[:rows]
             self.ui.draw_screen((cols, rows), r)
-            keys, raw = self.ui.get_input(raw_keys=True)  # pylint: disable=unpacking-non-sequence
+            keys, raw = self.ui.get_input(raw_keys=True)
             if "window resize" in keys:
                 cols, rows = self.ui.get_cols_rows()
             if not keys:
